[asterisk-commits] dlee: branch dlee/better-nicknames r401312 - in /team/dlee/better-nicknames: ...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Mon Oct 21 12:05:17 CDT 2013


Author: dlee
Date: Mon Oct 21 12:05:15 2013
New Revision: 401312

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=401312
Log:
s/getAll/list/

Modified:
    team/dlee/better-nicknames/res/ari/resource_applications.c
    team/dlee/better-nicknames/res/ari/resource_applications.h
    team/dlee/better-nicknames/res/ari/resource_bridges.c
    team/dlee/better-nicknames/res/ari/resource_bridges.h
    team/dlee/better-nicknames/res/ari/resource_channels.c
    team/dlee/better-nicknames/res/ari/resource_channels.h
    team/dlee/better-nicknames/res/ari/resource_endpoints.c
    team/dlee/better-nicknames/res/ari/resource_endpoints.h
    team/dlee/better-nicknames/res/ari/resource_recordings.c
    team/dlee/better-nicknames/res/ari/resource_recordings.h
    team/dlee/better-nicknames/res/ari/resource_sounds.c
    team/dlee/better-nicknames/res/ari/resource_sounds.h
    team/dlee/better-nicknames/res/res_ari_applications.c
    team/dlee/better-nicknames/res/res_ari_bridges.c
    team/dlee/better-nicknames/res/res_ari_channels.c
    team/dlee/better-nicknames/res/res_ari_endpoints.c
    team/dlee/better-nicknames/res/res_ari_recordings.c
    team/dlee/better-nicknames/res/res_ari_sounds.c
    team/dlee/better-nicknames/rest-api/api-docs/applications.json
    team/dlee/better-nicknames/rest-api/api-docs/bridges.json
    team/dlee/better-nicknames/rest-api/api-docs/channels.json
    team/dlee/better-nicknames/rest-api/api-docs/endpoints.json
    team/dlee/better-nicknames/rest-api/api-docs/recordings.json
    team/dlee/better-nicknames/rest-api/api-docs/sounds.json

Modified: team/dlee/better-nicknames/res/ari/resource_applications.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_applications.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_applications.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_applications.c Mon Oct 21 12:05:15 2013
@@ -41,8 +41,8 @@
 	return 0;
 }
 
-void ast_ari_applications_get_all(struct ast_variable *headers,
-	struct ast_ari_applications_get_all_args *args,
+void ast_ari_applications_list(struct ast_variable *headers,
+	struct ast_ari_applications_list_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct ao2_container *, apps, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_applications.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_applications.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_bridges.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_bridges.c Mon Oct 21 12:05:15 2013
@@ -600,8 +600,8 @@
 	ast_ari_response_no_content(response);
 }
 
-void ast_ari_bridges_get_all(struct ast_variable *headers,
-	struct ast_ari_bridges_get_all_args *args,
+void ast_ari_bridges_list(struct ast_variable *headers,
+	struct ast_ari_bridges_list_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct stasis_cache *, cache, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_bridges.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_bridges.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_channels.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_channels.c Mon Oct 21 12:05:15 2013
@@ -540,8 +540,8 @@
 	ast_ari_response_no_content(response);
 }
 
-void ast_ari_channels_get_all(struct ast_variable *headers,
-	struct ast_ari_channels_get_all_args *args,
+void ast_ari_channels_list(struct ast_variable *headers,
+	struct ast_ari_channels_list_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct stasis_cache *, cache, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_channels.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_channels.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_endpoints.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_endpoints.c Mon Oct 21 12:05:15 2013
@@ -33,8 +33,8 @@
 #include "asterisk/stasis.h"
 #include "asterisk/stasis_endpoints.h"
 
-void ast_ari_endpoints_get_all(struct ast_variable *headers,
-	struct ast_ari_endpoints_get_all_args *args,
+void ast_ari_endpoints_list(struct ast_variable *headers,
+	struct ast_ari_endpoints_list_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct stasis_cache *, cache, NULL, ao2_cleanup);
@@ -79,8 +79,8 @@
 
 	ast_ari_response_ok(response, ast_json_ref(json));
 }
-void ast_ari_endpoints_get_all_by_tech(struct ast_variable *headers,
-	struct ast_ari_endpoints_get_all_by_tech_args *args,
+void ast_ari_endpoints_list_by_tech(struct ast_variable *headers,
+	struct ast_ari_endpoints_list_by_tech_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct stasis_cache *, cache, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_endpoints.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_endpoints.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_recordings.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_recordings.c Mon Oct 21 12:05:15 2013
@@ -30,8 +30,8 @@
 #include "asterisk/stasis_app_recording.h"
 #include "resource_recordings.h"
 
-void ast_ari_recordings_get_all_stored(struct ast_variable *headers,
-	struct ast_ari_recordings_get_all_stored_args *args,
+void ast_ari_recordings_list_stored(struct ast_variable *headers,
+	struct ast_ari_recordings_list_stored_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct ao2_container *, recordings, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_recordings.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_recordings.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_sounds.c (original)
+++ team/dlee/better-nicknames/res/ari/resource_sounds.c Mon Oct 21 12:05:15 2013
@@ -96,7 +96,7 @@
 
 /*! \brief Generate a Sound structure as documented in sounds.json for the specified filename */
 static struct ast_json *create_sound_blob(const char *filename,
-	struct ast_ari_sounds_get_all_args *args)
+	struct ast_ari_sounds_list_args *args)
 {
 	RAII_VAR(struct ast_json *, sound, NULL, ast_json_unref);
 	RAII_VAR(struct ao2_container *, languages, NULL, ao2_cleanup);
@@ -164,7 +164,7 @@
 {
 	struct ast_json *sounds_array = arg;
 	char *filename = obj;
-	struct ast_ari_sounds_get_all_args *args = data;
+	struct ast_ari_sounds_list_args *args = data;
 	struct ast_json *sound_blob = create_sound_blob(filename, args);
 	if (!sound_blob) {
 		return 0;
@@ -174,8 +174,8 @@
 	return 0;
 }
 
-void ast_ari_sounds_get_all(struct ast_variable *headers,
-	struct ast_ari_sounds_get_all_args *args,
+void ast_ari_sounds_list(struct ast_variable *headers,
+	struct ast_ari_sounds_list_args *args,
 	struct ast_ari_response *response)
 {
 	RAII_VAR(struct ao2_container *, sound_files, NULL, ao2_cleanup);

Modified: team/dlee/better-nicknames/res/ari/resource_sounds.h
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_sounds.h?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_applications.c (original)
+++ team/dlee/better-nicknames/res/res_ari_applications.c Mon Oct 21 12:05:15 2013
@@ -58,17 +58,17 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_applications_get_all_cb(
+static void ast_ari_applications_list_cb(
 	struct ast_variable *get_params, struct ast_variable *path_vars,
 	struct ast_variable *headers, struct ast_ari_response *response)
 {
-	struct ast_ari_applications_get_all_args args = {};
+	struct ast_ari_applications_list_args args = {};
 #if defined(AST_DEVMODE)
 	int is_valid;
 	int code;
 #endif /* AST_DEVMODE */
 
-	ast_ari_applications_get_all(headers, &args, response);
+	ast_ari_applications_list(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -397,7 +397,7 @@
 static struct stasis_rest_handlers applications = {
 	.path_segment = "applications",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_applications_get_all_cb,
+		[AST_HTTP_GET] = ast_ari_applications_list_cb,
 	},
 	.num_children = 1,
 	.children = { &applications_applicationName, }

Modified: team/dlee/better-nicknames/res/res_ari_bridges.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_bridges.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_bridges.c (original)
+++ team/dlee/better-nicknames/res/res_ari_bridges.c Mon Oct 21 12:05:15 2013
@@ -58,17 +58,17 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_bridges_get_all_cb(
-	struct ast_variable *get_params, struct ast_variable *path_vars,
-	struct ast_variable *headers, struct ast_ari_response *response)
-{
-	struct ast_ari_bridges_get_all_args args = {};
-#if defined(AST_DEVMODE)
-	int is_valid;
-	int code;
-#endif /* AST_DEVMODE */
-
-	ast_ari_bridges_get_all(headers, &args, response);
+static void ast_ari_bridges_list_cb(
+	struct ast_variable *get_params, struct ast_variable *path_vars,
+	struct ast_variable *headers, struct ast_ari_response *response)
+{
+	struct ast_ari_bridges_list_args args = {};
+#if defined(AST_DEVMODE)
+	int is_valid;
+	int code;
+#endif /* AST_DEVMODE */
+
+	ast_ari_bridges_list(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -829,7 +829,7 @@
 static struct stasis_rest_handlers bridges = {
 	.path_segment = "bridges",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_bridges_get_all_cb,
+		[AST_HTTP_GET] = ast_ari_bridges_list_cb,
 		[AST_HTTP_POST] = ast_ari_bridges_create_cb,
 	},
 	.num_children = 1,

Modified: team/dlee/better-nicknames/res/res_ari_channels.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_channels.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_channels.c (original)
+++ team/dlee/better-nicknames/res/res_ari_channels.c Mon Oct 21 12:05:15 2013
@@ -58,17 +58,17 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_channels_get_all_cb(
-	struct ast_variable *get_params, struct ast_variable *path_vars,
-	struct ast_variable *headers, struct ast_ari_response *response)
-{
-	struct ast_ari_channels_get_all_args args = {};
-#if defined(AST_DEVMODE)
-	int is_valid;
-	int code;
-#endif /* AST_DEVMODE */
-
-	ast_ari_channels_get_all(headers, &args, response);
+static void ast_ari_channels_list_cb(
+	struct ast_variable *get_params, struct ast_variable *path_vars,
+	struct ast_variable *headers, struct ast_ari_response *response)
+{
+	struct ast_ari_channels_list_args args = {};
+#if defined(AST_DEVMODE)
+	int is_valid;
+	int code;
+#endif /* AST_DEVMODE */
+
+	ast_ari_channels_list(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -1249,7 +1249,7 @@
 static struct stasis_rest_handlers channels = {
 	.path_segment = "channels",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_channels_get_all_cb,
+		[AST_HTTP_GET] = ast_ari_channels_list_cb,
 		[AST_HTTP_POST] = ast_ari_channels_originate_cb,
 	},
 	.num_children = 1,

Modified: team/dlee/better-nicknames/res/res_ari_endpoints.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_endpoints.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_endpoints.c (original)
+++ team/dlee/better-nicknames/res/res_ari_endpoints.c Mon Oct 21 12:05:15 2013
@@ -58,17 +58,17 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_endpoints_get_all_cb(
+static void ast_ari_endpoints_list_cb(
 	struct ast_variable *get_params, struct ast_variable *path_vars,
 	struct ast_variable *headers, struct ast_ari_response *response)
 {
-	struct ast_ari_endpoints_get_all_args args = {};
+	struct ast_ari_endpoints_list_args args = {};
 #if defined(AST_DEVMODE)
 	int is_valid;
 	int code;
 #endif /* AST_DEVMODE */
 
-	ast_ari_endpoints_get_all(headers, &args, response);
+	ast_ari_endpoints_list(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -107,11 +107,11 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_endpoints_get_all_by_tech_cb(
+static void ast_ari_endpoints_list_by_tech_cb(
 	struct ast_variable *get_params, struct ast_variable *path_vars,
 	struct ast_variable *headers, struct ast_ari_response *response)
 {
-	struct ast_ari_endpoints_get_all_by_tech_args args = {};
+	struct ast_ari_endpoints_list_by_tech_args args = {};
 	struct ast_variable *i;
 #if defined(AST_DEVMODE)
 	int is_valid;
@@ -124,7 +124,7 @@
 		} else
 		{}
 	}
-	ast_ari_endpoints_get_all_by_tech(headers, &args, response);
+	ast_ari_endpoints_list_by_tech(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -231,7 +231,7 @@
 	.path_segment = "tech",
 	.is_wildcard = 1,
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_endpoints_get_all_by_tech_cb,
+		[AST_HTTP_GET] = ast_ari_endpoints_list_by_tech_cb,
 	},
 	.num_children = 1,
 	.children = { &endpoints_tech_resource, }
@@ -240,7 +240,7 @@
 static struct stasis_rest_handlers endpoints = {
 	.path_segment = "endpoints",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_endpoints_get_all_cb,
+		[AST_HTTP_GET] = ast_ari_endpoints_list_cb,
 	},
 	.num_children = 1,
 	.children = { &endpoints_tech, }

Modified: team/dlee/better-nicknames/res/res_ari_recordings.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_recordings.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_recordings.c (original)
+++ team/dlee/better-nicknames/res/res_ari_recordings.c Mon Oct 21 12:05:15 2013
@@ -58,17 +58,17 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_recordings_get_all_stored_cb(
-	struct ast_variable *get_params, struct ast_variable *path_vars,
-	struct ast_variable *headers, struct ast_ari_response *response)
-{
-	struct ast_ari_recordings_get_all_stored_args args = {};
-#if defined(AST_DEVMODE)
-	int is_valid;
-	int code;
-#endif /* AST_DEVMODE */
-
-	ast_ari_recordings_get_all_stored(headers, &args, response);
+static void ast_ari_recordings_list_stored_cb(
+	struct ast_variable *get_params, struct ast_variable *path_vars,
+	struct ast_variable *headers, struct ast_ari_response *response)
+{
+	struct ast_ari_recordings_list_stored_args args = {};
+#if defined(AST_DEVMODE)
+	int is_valid;
+	int code;
+#endif /* AST_DEVMODE */
+
+	ast_ari_recordings_list_stored(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -633,7 +633,7 @@
 static struct stasis_rest_handlers recordings_stored = {
 	.path_segment = "stored",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_recordings_get_all_stored_cb,
+		[AST_HTTP_GET] = ast_ari_recordings_list_stored_cb,
 	},
 	.num_children = 1,
 	.children = { &recordings_stored_recordingName, }

Modified: team/dlee/better-nicknames/res/res_ari_sounds.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_sounds.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/res_ari_sounds.c (original)
+++ team/dlee/better-nicknames/res/res_ari_sounds.c Mon Oct 21 12:05:15 2013
@@ -58,11 +58,11 @@
  * \param headers HTTP headers.
  * \param[out] response Response to the HTTP request.
  */
-static void ast_ari_sounds_get_all_cb(
+static void ast_ari_sounds_list_cb(
 	struct ast_variable *get_params, struct ast_variable *path_vars,
 	struct ast_variable *headers, struct ast_ari_response *response)
 {
-	struct ast_ari_sounds_get_all_args args = {};
+	struct ast_ari_sounds_list_args args = {};
 	struct ast_variable *i;
 #if defined(AST_DEVMODE)
 	int is_valid;
@@ -78,7 +78,7 @@
 		} else
 		{}
 	}
-	ast_ari_sounds_get_all(headers, &args, response);
+	ast_ari_sounds_list(headers, &args, response);
 #if defined(AST_DEVMODE)
 	code = response->response_code;
 
@@ -181,7 +181,7 @@
 static struct stasis_rest_handlers sounds = {
 	.path_segment = "sounds",
 	.callbacks = {
-		[AST_HTTP_GET] = ast_ari_sounds_get_all_cb,
+		[AST_HTTP_GET] = ast_ari_sounds_list_cb,
 	},
 	.num_children = 1,
 	.children = { &sounds_soundId, }

Modified: team/dlee/better-nicknames/rest-api/api-docs/applications.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/applications.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/applications.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/applications.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List all applications.",
-					"nickname": "getAll",
+					"nickname": "list",
 					"responseClass": "List[Application]"
 				}
 			]

Modified: team/dlee/better-nicknames/rest-api/api-docs/bridges.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/bridges.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/bridges.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/bridges.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List all active bridges in Asterisk.",
-					"nickname": "getAll",
+					"nickname": "list",
 					"responseClass": "List[Bridge]"
 				},
 				{

Modified: team/dlee/better-nicknames/rest-api/api-docs/channels.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/channels.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/channels.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/channels.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List all active channels in Asterisk.",
-					"nickname": "getAll",
+					"nickname": "list",
 					"responseClass": "List[Channel]"
 				},
 				{

Modified: team/dlee/better-nicknames/rest-api/api-docs/endpoints.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/endpoints.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/endpoints.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/endpoints.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List all endpoints.",
-					"nickname": "getAll",
+					"nickname": "list",
 					"responseClass": "List[Endpoint]"
 				}
 			]
@@ -26,7 +26,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List available endoints for a given endpoint technology.",
-					"nickname": "getAllByTech",
+					"nickname": "listByTech",
 					"responseClass": "List[Endpoint]",
 					"parameters": [
 						{

Modified: team/dlee/better-nicknames/rest-api/api-docs/recordings.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/recordings.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/recordings.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/recordings.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List recordings that are complete.",
-					"nickname": "getAllStored",
+					"nickname": "listStored",
 					"responseClass": "List[StoredRecording]"
 				}
 			]

Modified: team/dlee/better-nicknames/rest-api/api-docs/sounds.json
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/rest-api/api-docs/sounds.json?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/rest-api/api-docs/sounds.json (original)
+++ team/dlee/better-nicknames/rest-api/api-docs/sounds.json Mon Oct 21 12:05:15 2013
@@ -14,7 +14,7 @@
 				{
 					"httpMethod": "GET",
 					"summary": "List all sounds.",
-					"nickname": "getAll",
+					"nickname": "list",
 					"responseClass": "List[Sound]",
 					"parameters": [
 						{




More information about the asterisk-commits mailing list
--- team/dlee/better-nicknames/res/ari/resource_applications.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_applications.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_applications_get_all() */
-struct ast_ari_applications_get_all_args {
+/*! \brief Argument struct for ast_ari_applications_list() */
+struct ast_ari_applications_list_args {
 };
 /*!
  * \brief List all applications.
@@ -49,7 +49,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_applications_get_all(struct ast_variable *headers, struct ast_ari_applications_get_all_args *args, struct ast_ari_response *response);
+void ast_ari_applications_list(struct ast_variable *headers, struct ast_ari_applications_list_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_applications_get() */
 struct ast_ari_applications_get_args {
 	/*! \brief Application's name */

Modified: team/dlee/better-nicknames/res/ari/resource_bridges.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_bridges.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_bridges.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_bridges.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_bridges_get_all() */
-struct ast_ari_bridges_get_all_args {
+/*! \brief Argument struct for ast_ari_bridges_list() */
+struct ast_ari_bridges_list_args {
 };
 /*!
  * \brief List all active bridges in Asterisk.
@@ -49,7 +49,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_bridges_get_all(struct ast_variable *headers, struct ast_ari_bridges_get_all_args *args, struct ast_ari_response *response);
+void ast_ari_bridges_list(struct ast_variable *headers, struct ast_ari_bridges_list_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_bridges_create() */
 struct ast_ari_bridges_create_args {
 	/*! \brief Type of bridge to create. */

Modified: team/dlee/better-nicknames/res/ari/resource_channels.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_channels.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_channels.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_channels.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_channels_get_all() */
-struct ast_ari_channels_get_all_args {
+/*! \brief Argument struct for ast_ari_channels_list() */
+struct ast_ari_channels_list_args {
 };
 /*!
  * \brief List all active channels in Asterisk.
@@ -49,7 +49,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_channels_get_all(struct ast_variable *headers, struct ast_ari_channels_get_all_args *args, struct ast_ari_response *response);
+void ast_ari_channels_list(struct ast_variable *headers, struct ast_ari_channels_list_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_channels_originate() */
 struct ast_ari_channels_originate_args {
 	/*! \brief Endpoint to call. */

Modified: team/dlee/better-nicknames/res/ari/resource_endpoints.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_endpoints.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_endpoints.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_endpoints.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_endpoints_get_all() */
-struct ast_ari_endpoints_get_all_args {
+/*! \brief Argument struct for ast_ari_endpoints_list() */
+struct ast_ari_endpoints_list_args {
 };
 /*!
  * \brief List all endpoints.
@@ -49,9 +49,9 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_endpoints_get_all(struct ast_variable *headers, struct ast_ari_endpoints_get_all_args *args, struct ast_ari_response *response);
-/*! \brief Argument struct for ast_ari_endpoints_get_all_by_tech() */
-struct ast_ari_endpoints_get_all_by_tech_args {
+void ast_ari_endpoints_list(struct ast_variable *headers, struct ast_ari_endpoints_list_args *args, struct ast_ari_response *response);
+/*! \brief Argument struct for ast_ari_endpoints_list_by_tech() */
+struct ast_ari_endpoints_list_by_tech_args {
 	/*! \brief Technology of the endpoints (sip,iax2,...) */
 	const char *tech;
 };
@@ -62,7 +62,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_endpoints_get_all_by_tech(struct ast_variable *headers, struct ast_ari_endpoints_get_all_by_tech_args *args, struct ast_ari_response *response);
+void ast_ari_endpoints_list_by_tech(struct ast_variable *headers, struct ast_ari_endpoints_list_by_tech_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_endpoints_get() */
 struct ast_ari_endpoints_get_args {
 	/*! \brief Technology of the endpoint */

Modified: team/dlee/better-nicknames/res/ari/resource_recordings.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_recordings.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_recordings.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_recordings.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_recordings_get_all_stored() */
-struct ast_ari_recordings_get_all_stored_args {
+/*! \brief Argument struct for ast_ari_recordings_list_stored() */
+struct ast_ari_recordings_list_stored_args {
 };
 /*!
  * \brief List recordings that are complete.
@@ -49,7 +49,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_recordings_get_all_stored(struct ast_variable *headers, struct ast_ari_recordings_get_all_stored_args *args, struct ast_ari_response *response);
+void ast_ari_recordings_list_stored(struct ast_variable *headers, struct ast_ari_recordings_list_stored_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_recordings_get_stored() */
 struct ast_ari_recordings_get_stored_args {
 	/*! \brief The name of the recording */

Modified: team/dlee/better-nicknames/res/ari/resource_sounds.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/ari/resource_sounds.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================
--- team/dlee/better-nicknames/res/ari/resource_sounds.h (original)
+++ team/dlee/better-nicknames/res/ari/resource_sounds.h Mon Oct 21 12:05:15 2013
@@ -39,8 +39,8 @@
 
 #include "asterisk/ari.h"
 
-/*! \brief Argument struct for ast_ari_sounds_get_all() */
-struct ast_ari_sounds_get_all_args {
+/*! \brief Argument struct for ast_ari_sounds_list() */
+struct ast_ari_sounds_list_args {
 	/*! \brief Lookup sound for a specific language. */
 	const char *lang;
 	/*! \brief Lookup sound in a specific format. */
@@ -53,7 +53,7 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void ast_ari_sounds_get_all(struct ast_variable *headers, struct ast_ari_sounds_get_all_args *args, struct ast_ari_response *response);
+void ast_ari_sounds_list(struct ast_variable *headers, struct ast_ari_sounds_list_args *args, struct ast_ari_response *response);
 /*! \brief Argument struct for ast_ari_sounds_get() */
 struct ast_ari_sounds_get_args {
 	/*! \brief Sound's id */

Modified: team/dlee/better-nicknames/res/res_ari_applications.c
URL: http://svnview.digium.com/svn/asterisk/team/dlee/better-nicknames/res/res_ari_applications.c?view=diff&rev=401312&r1=401311&r2=401312
==============================================================================